@@ -105,7 +105,7 @@
 
 #define tmpdir "/tmp"
 #define program "empty"
-#define version "0.6.12b" 
+#define version "0.6.15b" 
 
 /* -------------------------------------------------------------------------- */
 static void usage(void);
@@ -457,14 +457,8 @@ int main (int argc, char *argv[]) {
         /* Fork does not work properly */
 	if (pid > 0) 
 		(void)exit(0);
-	
-	for (i = 1; i < 32; i++) 
-#if defined(__AIX) || defined(__hpux__) || defined(__OSF1) || defined(__SVR4) && !defined(__SCO_VERSION__)
-	    if (i != SIGCHLD)
-#endif
-		signal(i, fsignal);
-
 	pid = getpid();				/* MY PID */
+	
 	if (pflg) {
 		if ((pfd = open(pfile, O_CREAT|O_WRONLY, S_IRWXU)) == -1)
 			(void)syslog(LOG_NOTICE,
@@ -513,9 +507,6 @@ int main (int argc, char *argv[]) {
 		/* See the same definition for Solaris & UW several lines below */
 		if (grantpt(master) == -1)
 			(void)perrxslog(255, "Can't grant access to slave part of PTY: %m");
-
-		/* grantpt() may fail if SIGCHLD was previously set */
-		signal(SIGCHLD, fsignal);
 	#endif
 	
 	if (unlockpt(master) == -1)
@@ -527,12 +518,12 @@ int main (int argc, char *argv[]) {
 	#if defined(__SVR4) && !defined(__SCO_VERSION__)
 		if (grantpt(master) == -1)
 			(void)perrxslog(255, "Can't grant access to slave part of PTY: %m");
-
-		/* grantpt() may fail if SIGCHLD was previously set */
-		signal(SIGCHLD, fsignal);
 	#endif
 #endif /* !defined(__SVR4) && !defined(__hpux__) && !defined(__AIX) */
- 
+
+	for (i = 1; i < 32; i++)
+		signal(i, fsignal);	/* hook signals */
+
 	if ((child = fork()) < 0) {
 		(void)clean();
 		(void)perrxslog(255, "Fatal fork at creating desired process");
